#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobExecution :
    def __init__( self):
        self.startDate = None
        self.endDate = None
        self.domainUid = None
        self.status = None
        self.jobId = None
        self.execGroup = None
        self.id = None
        pass

class __JobExecutionSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = JobExecution()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        startDateValue = value['startDate']
        instance.startDate = serder.DATE.parse(startDateValue)
        endDateValue = value['endDate']
        instance.endDate = serder.DATE.parse(endDateValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
        from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
        statusValue = value['status']
        instance.status = __JobExitStatusSerDer__().parse(statusValue)
        jobIdValue = value['jobId']
        instance.jobId = serder.STRING.parse(jobIdValue)
        execGroupValue = value['execGroup']
        instance.execGroup = serder.STRING.parse(execGroupValue)
        idValue = value['id']
        instance.id = serder.INT.parse(idValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        startDateValue = value.startDate
        instance["startDate"] = serder.DATE.encode(startDateValue)
        endDateValue = value.endDate
        instance["endDate"] = serder.DATE.encode(endDateValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
        from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
        statusValue = value.status
        instance["status"] = __JobExitStatusSerDer__().encode(statusValue)
        jobIdValue = value.jobId
        instance["jobId"] = serder.STRING.encode(jobIdValue)
        execGroupValue = value.execGroup
        instance["execGroup"] = serder.STRING.encode(execGroupValue)
        idValue = value.id
        instance["id"] = serder.INT.encode(idValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailConversation_VERSION = "4.1.62024"

class IMailConversation(BaseEndpoint):
    def __init__(self, apiKey, url ,conversationContainer ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/mail_conversation/{conversationContainer}'
        self.conversationContainer_ = conversationContainer
        self.base = self.base.replace('{conversationContainer}',conversationContainer)

    def getComplete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailConversation_VERSION}, data = __encoded__);
        from netbluemind.backend.mail.api.Conversation import Conversation
        from netbluemind.backend.mail.api.Conversation import __ConversationSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__ConversationSerDer__()), response)
    def byFolder (self, folder , filter ):
        postUri = "";
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        __data__ = __ItemFlagFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'folder': folder    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailConversation_VERSION}, data = __encoded__);
        from netbluemind.backend.mail.api.Conversation import Conversation
        from netbluemind.backend.mail.api.Conversation import __ConversationSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ConversationSerDer__())), response)
    def removeMessage (self, containerUid , itemId ):
        postUri = "/{containerUid}/{itemId}/_message";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}",containerUid);
        postUri = postUri.replace("{itemId}",itemId);
        queryParams = {    };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailConversation_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CertData :
    def __init__( self):
        self.sslCertificateEngine = None
        self.certificateAuthority = None
        self.certificate = None
        self.privateKey = None
        self.domainUid = None
        self.email = None
        pass

class __CertDataSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = CertData()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.system.api.CertDataCertificateDomainEngine import CertDataCertificateDomainEngine
        from netbluemind.system.api.CertDataCertificateDomainEngine import __CertDataCertificateDomainEngineSerDer__
        sslCertificateEngineValue = value['sslCertificateEngine']
        instance.sslCertificateEngine = __CertDataCertificateDomainEngineSerDer__().parse(sslCertificateEngineValue)
        certificateAuthorityValue = value['certificateAuthority']
        instance.certificateAuthority = serder.STRING.parse(certificateAuthorityValue)
        certificateValue = value['certificate']
        instance.certificate = serder.STRING.parse(certificateValue)
        privateKeyValue = value['privateKey']
        instance.privateKey = serder.STRING.parse(privateKeyValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        emailValue = value['email']
        instance.email = serder.STRING.parse(emailValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.system.api.CertDataCertificateDomainEngine import CertDataCertificateDomainEngine
        from netbluemind.system.api.CertDataCertificateDomainEngine import __CertDataCertificateDomainEngineSerDer__
        sslCertificateEngineValue = value.sslCertificateEngine
        instance["sslCertificateEngine"] = __CertDataCertificateDomainEngineSerDer__().encode(sslCertificateEngineValue)
        certificateAuthorityValue = value.certificateAuthority
        instance["certificateAuthority"] = serder.STRING.encode(certificateAuthorityValue)
        certificateValue = value.certificate
        instance["certificate"] = serder.STRING.encode(certificateValue)
        privateKeyValue = value.privateKey
        instance["privateKey"] = serder.STRING.encode(privateKeyValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        emailValue = value.email
        instance["email"] = serder.STRING.encode(emailValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.BaseDirEntry import BaseDirEntry
from netbluemind.directory.api.BaseDirEntry import __BaseDirEntrySerDer__
class DirEntry (BaseDirEntry):
    def __init__( self):
        BaseDirEntry.__init__(self)
        self.path = None
        self.email = None
        self.hidden = None
        self.system = None
        self.archived = None
        self.emails = None
        self.orgUnitUid = None
        self.orgUnitPath = None
        self.dataLocation = None
        pass

class __DirEntrySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = DirEntry()
        __BaseDirEntrySerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        pathValue = value['path']
        instance.path = serder.STRING.parse(pathValue)
        emailValue = value['email']
        instance.email = serder.STRING.parse(emailValue)
        hiddenValue = value['hidden']
        instance.hidden = serder.BOOLEAN.parse(hiddenValue)
        systemValue = value['system']
        instance.system = serder.BOOLEAN.parse(systemValue)
        archivedValue = value['archived']
        instance.archived = serder.BOOLEAN.parse(archivedValue)
        from netbluemind.core.api.Email import Email
        from netbluemind.core.api.Email import __EmailSerDer__
        emailsValue = value['emails']
        instance.emails = serder.ListSerDer(__EmailSerDer__()).parse(emailsValue)
        orgUnitUidValue = value['orgUnitUid']
        instance.orgUnitUid = serder.STRING.parse(orgUnitUidValue)
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        orgUnitPathValue = value['orgUnitPath']
        instance.orgUnitPath = __OrgUnitPathSerDer__().parse(orgUnitPathValue)
        dataLocationValue = value['dataLocation']
        instance.dataLocation = serder.STRING.parse(dataLocationValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __BaseDirEntrySerDer__().encodeInternal(value,instance)

        pathValue = value.path
        instance["path"] = serder.STRING.encode(pathValue)
        emailValue = value.email
        instance["email"] = serder.STRING.encode(emailValue)
        hiddenValue = value.hidden
        instance["hidden"] = serder.BOOLEAN.encode(hiddenValue)
        systemValue = value.system
        instance["system"] = serder.BOOLEAN.encode(systemValue)
        archivedValue = value.archived
        instance["archived"] = serder.BOOLEAN.encode(archivedValue)
        from netbluemind.core.api.Email import Email
        from netbluemind.core.api.Email import __EmailSerDer__
        emailsValue = value.emails
        instance["emails"] = serder.ListSerDer(__EmailSerDer__()).encode(emailsValue)
        orgUnitUidValue = value.orgUnitUid
        instance["orgUnitUid"] = serder.STRING.encode(orgUnitUidValue)
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        orgUnitPathValue = value.orgUnitPath
        instance["orgUnitPath"] = __OrgUnitPathSerDer__().encode(orgUnitPathValue)
        dataLocationValue = value.dataLocation
        instance["dataLocation"] = serder.STRING.encode(dataLocationValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementVAlarm :
    def __init__( self):
        self.action = None
        self.trigger = None
        self.description = None
        self.duration = None
        self.repeat = None
        self.summary = None
        pass

class __ICalendarElementVAlarmSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ICalendarElementVAlarm()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.icalendar.api.ICalendarElementVAlarmAction import ICalendarElementVAlarmAction
        from netbluemind.icalendar.api.ICalendarElementVAlarmAction import __ICalendarElementVAlarmActionSerDer__
        actionValue = value['action']
        instance.action = __ICalendarElementVAlarmActionSerDer__().parse(actionValue)
        triggerValue = value['trigger']
        instance.trigger = serder.INT.parse(triggerValue)
        descriptionValue = value['description']
        instance.description = serder.STRING.parse(descriptionValue)
        durationValue = value['duration']
        instance.duration = serder.INT.parse(durationValue)
        repeatValue = value['repeat']
        instance.repeat = serder.INT.parse(repeatValue)
        summaryValue = value['summary']
        instance.summary = serder.STRING.parse(summaryValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.icalendar.api.ICalendarElementVAlarmAction import ICalendarElementVAlarmAction
        from netbluemind.icalendar.api.ICalendarElementVAlarmAction import __ICalendarElementVAlarmActionSerDer__
        actionValue = value.action
        instance["action"] = __ICalendarElementVAlarmActionSerDer__().encode(actionValue)
        triggerValue = value.trigger
        instance["trigger"] = serder.INT.encode(triggerValue)
        descriptionValue = value.description
        instance["description"] = serder.STRING.encode(descriptionValue)
        durationValue = value.duration
        instance["duration"] = serder.INT.encode(durationValue)
        repeatValue = value.repeat
        instance["repeat"] = serder.INT.encode(repeatValue)
        summaryValue = value.summary
        instance["summary"] = serder.STRING.encode(summaryValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxes_VERSION = "4.1.62024"

class IMailboxes(BaseEndpoint):
    def __init__(self, apiKey, url ,domainUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/mailboxes/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}',domainUid)

    def getMailboxConfig (self, uid ):
        postUri = "/{uid}/_config";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.MailboxConfig import MailboxConfig
        from netbluemind.mailbox.api.MailboxConfig import __MailboxConfigSerDer__
        return self.handleResult__(__MailboxConfigSerDer__(), response)
    def update (self, uid , mailbox ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        __data__ = __MailboxSerDer__().encode(mailbox)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def byName (self, name ):
        postUri = "/_byname";
        __data__ = None
        __encoded__ = None
        queryParams = {  'name': name   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)
    def delete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setMailboxFilter (self, mailboxUid , filter ):
        postUri = "/{mailboxUid}/_filter";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}",mailboxUid);
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        __data__ = __MailFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getUnreadMessagesCount (self):
        postUri = "/_unread";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(serder.INT, response)
    def listUids (self):
        postUri = "/_listUids";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def setMailboxAccessControlList (self, mailboxUid , accessControlEntries ):
        postUri = "/{mailboxUid}/_acls";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}",mailboxUid);
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        __data__ = serder.ListSerDer(__AccessControlEntrySerDer__()).encode(accessControlEntries)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def byEmail (self, email ):
        postUri = "/_byemail";
        __data__ = None
        __encoded__ = None
        queryParams = {  'email': email   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)
    def create (self, uid , mailbox ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        __data__ = __MailboxSerDer__().encode(mailbox)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def byRouting (self, email ):
        postUri = "/_byRouting";
        __data__ = None
        __encoded__ = None
        queryParams = {  'email': email   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def checkAll (self):
        postUri = "/_check-all";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def multipleGet (self, uids ):
        postUri = "/_mget";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxSerDer__())), response)
    def checkAndRepair (self, uid ):
        postUri = "/{uid}/_check-and-repair";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def getMailboxFilter (self, mailboxUid ):
        postUri = "/{mailboxUid}/_filter";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}",mailboxUid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        return self.handleResult__(__MailFilterSerDer__(), response)
    def getMailboxAccessControlList (self, mailboxUid ):
        postUri = "/{mailboxUid}/_acls";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}",mailboxUid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        return self.handleResult__(serder.ListSerDer(__AccessControlEntrySerDer__()), response)
    def check (self, uid ):
        postUri = "/{uid}/_check";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def list (self):
        postUri = "/_list";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxSerDer__())), response)
    def setDomainFilter (self, filter ):
        postUri = "/_filter";
        __data__ = None
        __encoded__ = None
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        __data__ = __MailFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getMailboxQuota (self, uid ):
        postUri = "/{uid}/_quota";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.MailboxQuota import MailboxQuota
        from netbluemind.mailbox.api.MailboxQuota import __MailboxQuotaSerDer__
        return self.handleResult__(__MailboxQuotaSerDer__(), response)
    def getComplete (self, uid ):
        postUri = "/{uid}/complete";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.Mailbox import Mailbox
        from netbluemind.mailbox.api.Mailbox import __MailboxSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxSerDer__()), response)
    def getDomainFilter (self):
        postUri = "/_filter";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.mailbox.api.MailFilter import MailFilter
        from netbluemind.mailbox.api.MailFilter import __MailFilterSerDer__
        return self.handleResult__(__MailFilterSerDer__(), response)
    def byType (self, email ):
        postUri = "/_byType";
        __data__ = None
        __encoded__ = None
        queryParams = {  'email': email   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def checkAndRepairAll (self):
        postUri = "/_check-and-repair-all";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxes_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MailFilterRule :
    def __init__( self):
        self.name = None
        self.criteria = None
        self.star = None
        self.read = None
        self.delete = None
        self.discard = None
        self.forward = None
        self.deliver = None
        self.active = None
        self.stop = None
        pass

class __MailFilterRuleSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = MailFilterRule()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        criteriaValue = value['criteria']
        instance.criteria = serder.STRING.parse(criteriaValue)
        starValue = value['star']
        instance.star = serder.BOOLEAN.parse(starValue)
        readValue = value['read']
        instance.read = serder.BOOLEAN.parse(readValue)
        deleteValue = value['delete']
        instance.delete = serder.BOOLEAN.parse(deleteValue)
        discardValue = value['discard']
        instance.discard = serder.BOOLEAN.parse(discardValue)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        forwardValue = value['forward']
        instance.forward = __MailFilterForwardingSerDer__().parse(forwardValue)
        deliverValue = value['deliver']
        instance.deliver = serder.STRING.parse(deliverValue)
        activeValue = value['active']
        instance.active = serder.BOOLEAN.parse(activeValue)
        stopValue = value['stop']
        instance.stop = serder.BOOLEAN.parse(stopValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        criteriaValue = value.criteria
        instance["criteria"] = serder.STRING.encode(criteriaValue)
        starValue = value.star
        instance["star"] = serder.BOOLEAN.encode(starValue)
        readValue = value.read
        instance["read"] = serder.BOOLEAN.encode(readValue)
        deleteValue = value.delete
        instance["delete"] = serder.BOOLEAN.encode(deleteValue)
        discardValue = value.discard
        instance["discard"] = serder.BOOLEAN.encode(discardValue)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        forwardValue = value.forward
        instance["forward"] = __MailFilterForwardingSerDer__().encode(forwardValue)
        deliverValue = value.deliver
        instance["deliver"] = serder.STRING.encode(deliverValue)
        activeValue = value.active
        instance["active"] = serder.BOOLEAN.encode(activeValue)
        stopValue = value.stop
        instance["stop"] = serder.BOOLEAN.encode(stopValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IAuthentication_VERSION = "4.1.62024"

class IAuthentication(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/auth'

    def getCurrentUser (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.AuthUser import AuthUser
        from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
        return self.handleResult__(__AuthUserSerDer__(), response)
    def su (self, login ):
        postUri = "/_su";
        __data__ = None
        __encoded__ = None
        queryParams = {  'login': login   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)
    def ping (self):
        postUri = "/ping";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def login (self, login , password , origin ):
        postUri = "/login";
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'login': login   , 'origin': origin   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)
    def loginWithParams (self, login , password , origin , interactive ):
        postUri = "/loginWithParams";
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'login': login   , 'origin': origin  , 'interactive': interactive   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)
    def logout (self):
        postUri = "/logout";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def suWithParams (self, login , interactive ):
        postUri = "/_suWithParams";
        __data__ = None
        __encoded__ = None
        queryParams = {  'login': login  , 'interactive': interactive   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)
    def validate (self, login , password , origin ):
        postUri = "/validate";
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'login': login   , 'origin': origin   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAuthentication_VERSION}, data = __encoded__);
        from netbluemind.authentication.api.ValidationKind import ValidationKind
        from netbluemind.authentication.api.ValidationKind import __ValidationKindSerDer__
        return self.handleResult__(__ValidationKindSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class User (DirBaseValue):
    def __init__( self):
        DirBaseValue.__init__(self)
        self.login = None
        self.password = None
        self.passwordLastChange = None
        self.passwordMustChange = None
        self.passwordNeverExpires = None
        self.contactInfos = None
        self.routing = None
        self.accountType = None
        self.quota = None
        self.mailboxCopyGuid = None
        self.properties = None
        pass

class __UserSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = User()
        __DirBaseValueSerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        loginValue = value['login']
        instance.login = serder.STRING.parse(loginValue)
        passwordValue = value['password']
        instance.password = serder.STRING.parse(passwordValue)
        passwordLastChangeValue = value['passwordLastChange']
        instance.passwordLastChange = serder.DATE.parse(passwordLastChangeValue)
        passwordMustChangeValue = value['passwordMustChange']
        instance.passwordMustChange = serder.BOOLEAN.parse(passwordMustChangeValue)
        passwordNeverExpiresValue = value['passwordNeverExpires']
        instance.passwordNeverExpires = serder.BOOLEAN.parse(passwordNeverExpiresValue)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        contactInfosValue = value['contactInfos']
        instance.contactInfos = __VCardSerDer__().parse(contactInfosValue)
        from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
        from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
        routingValue = value['routing']
        instance.routing = __MailboxRoutingSerDer__().parse(routingValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value['accountType']
        instance.accountType = __BaseDirEntryAccountTypeSerDer__().parse(accountTypeValue)
        quotaValue = value['quota']
        instance.quota = serder.INT.parse(quotaValue)
        mailboxCopyGuidValue = value['mailboxCopyGuid']
        instance.mailboxCopyGuid = serder.STRING.parse(mailboxCopyGuidValue)
        propertiesValue = value['properties']
        instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __DirBaseValueSerDer__().encodeInternal(value,instance)

        loginValue = value.login
        instance["login"] = serder.STRING.encode(loginValue)
        passwordValue = value.password
        instance["password"] = serder.STRING.encode(passwordValue)
        passwordLastChangeValue = value.passwordLastChange
        instance["passwordLastChange"] = serder.DATE.encode(passwordLastChangeValue)
        passwordMustChangeValue = value.passwordMustChange
        instance["passwordMustChange"] = serder.BOOLEAN.encode(passwordMustChangeValue)
        passwordNeverExpiresValue = value.passwordNeverExpires
        instance["passwordNeverExpires"] = serder.BOOLEAN.encode(passwordNeverExpiresValue)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        contactInfosValue = value.contactInfos
        instance["contactInfos"] = __VCardSerDer__().encode(contactInfosValue)
        from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
        from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
        routingValue = value.routing
        instance["routing"] = __MailboxRoutingSerDer__().encode(routingValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value.accountType
        instance["accountType"] = __BaseDirEntryAccountTypeSerDer__().encode(accountTypeValue)
        quotaValue = value.quota
        instance["quota"] = serder.INT.encode(quotaValue)
        mailboxCopyGuidValue = value.mailboxCopyGuid
        instance["mailboxCopyGuid"] = serder.STRING.encode(mailboxCopyGuidValue)
        propertiesValue = value.properties
        instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
        return instance

